@@ -7,9 +7,11 @@ from .collector import SettingsCollector  # noqa: W0611
 from .defaults import sc_defaults  # noqa: W0611
 from .exceptions import (  # noqa: W0611
     SC_Exception, SC_ConfigError, SC_WeirdBugError, SC_NotALoader,
+    SC_SettingsError,
 )
 from .manager import SC_LoadersManager  # noqa: W0611
 from .setting import SC_Setting  # noqa: W0611
+from .settings import SC_Settings, sc_settings  # noqa: W0611
 from .value import SC_Value  # noqa: W0611
 from .test import SCTest, sc_test_print_expected, sc_test_run  # noqa: W0611
 from .undef import SC_undef  # noqa: W0611
@@ -21,4 +23,5 @@ from .loaders.django import SC_DjangoLoader  # noqa: W0611
 from .loaders.env import SC_EnvironLoader  # noqa: W0611
 from .loaders.flask import SC_FlaskLoader  # noqa: W0611
 from .loaders.pyramid import SC_PyramidLoader  # noqa: W0611
+from .loaders.settings import SC_SettingsLoader  # noqa: W0611
 from .loaders.turbogears import SC_TurboGearsLoader  # noqa: W0611
